@@ -1,16 +1,16 @@
 # -*- encoding: utf-8 -*-
 """Task representation of evergreen."""
-from __future__ import absolute_import, annotations
+from __future__ import absolute_import
 
 from datetime import timedelta
 from enum import IntEnum
-from typing import Any, Dict, Iterable, List, Optional, TYPE_CHECKING
+from typing import Any, Callable, Dict, Iterable, List, Optional, TYPE_CHECKING
 
 from evergreen.base import _BaseEvergreenObject, evg_attrib, evg_datetime_attrib
 
 if TYPE_CHECKING:
     from evergreen.api import EvergreenApi
-    from evergreen.tst import Tst
+    from evergreen.tst import Tst  # noqa: F401
 
 EVG_SUCCESS_STATUS = "success"
 EVG_SYSTEM_FAILURE_STATUS = "system"
@@ -29,7 +29,7 @@ class Artifact(_BaseEvergreenObject):
     visibility = evg_attrib("visibility")
     ignore_for_fetch = evg_attrib("ignore_for_fetch")
 
-    def __init__(self, json: Dict[str, Any], api: EvergreenApi) -> None:
+    def __init__(self, json: Dict[str, Any], api: "EvergreenApi") -> None:
         """Create an instance of an evergreen task artifact."""
         super(Artifact, self).__init__(json, api)
 
@@ -44,7 +44,7 @@ class StatusScore(IntEnum):
     UNDISPATCHED = 5
 
     @classmethod
-    def get_task_status_score(cls, task: Task) -> StatusScore:
+    def get_task_status_score(cls, task: "Task") -> "StatusScore":
         """
         Retrieve the status score based on the task status.
 
@@ -69,7 +69,7 @@ class StatusDetails(_BaseEvergreenObject):
     desc = evg_attrib("desc")
     timed_out = evg_attrib("timed_out")
 
-    def __init__(self, json: Dict[str, Any], api: EvergreenApi) -> None:
+    def __init__(self, json: Dict[str, Any], api: "EvergreenApi") -> None:
         """Create an instance of an evergreen task status details."""
         super(StatusDetails, self).__init__(json, api)
 
@@ -90,6 +90,7 @@ class Task(_BaseEvergreenObject):
     est_wait_to_start_ms = evg_attrib("est_wait_to_start_ms")
     estimated_cost = evg_attrib("estimated_cost")
     execution = evg_attrib("execution")
+    execution_tasks = evg_attrib("execution_tasks")
     expected_duration_ms = evg_attrib("expected_duration_ms")
     finish_time = evg_datetime_attrib("finish_time")
     generate_task = evg_attrib("generate_task")
@@ -111,7 +112,7 @@ class Task(_BaseEvergreenObject):
     time_taken_ms = evg_attrib("time_taken_ms")
     version_id = evg_attrib("version_id")
 
-    def __init__(self, json: Dict[str, Any], api: EvergreenApi) -> None:
+    def __init__(self, json: Dict[str, Any], api: "EvergreenApi") -> None:
         """Create an instance of an evergreen task."""
         super(Task, self).__init__(json, api)
         self._logs_map: Optional[Dict[Any, Any]] = None
@@ -174,7 +175,7 @@ class Task(_BaseEvergreenObject):
         """
         return StatusScore.get_task_status_score(self)
 
-    def get_execution(self, execution: int) -> Optional[Task]:
+    def get_execution(self, execution: int) -> Optional["Task"]:
         """
         Get the task info for the specified execution.
 
@@ -191,6 +192,20 @@ class Task(_BaseEvergreenObject):
 
         return None
 
+    def get_execution_or_self(self, execution: int) -> "Task":
+        """
+        Get the specified execution if it exists.
+
+        If the specified execution does not exist, return self.
+
+        :param execution: Index of execution.
+        :return: Task info for specified execution or self.
+        """
+        task_execution = self.get_execution(execution)
+        if task_execution:
+            return task_execution
+        return self
+
     def wait_time(self) -> Optional[timedelta]:
         """
         Get the time taken until the task started running.
@@ -257,15 +272,49 @@ class Task(_BaseEvergreenObject):
         """
         return self.scheduled_time and not self.finish_time
 
-    def get_tests(self, status: Optional[str] = None, execution: Optional[int] = None) -> List[Tst]:
+    def get_tests(
+        self, status: Optional[str] = None, execution: Optional[int] = None
+    ) -> List["Tst"]:
         """
         Get the test results for this task.
 
         :param status: Only return tests with the given status.
-        :param execution: Return test results for the specified execution.
+        :param execution: Return results for specified execution, if specified.
         :return: List of test results for the task.
         """
-        return self._api.tests_by_task(self.task_id, status=status, execution=execution)
+        return self._api.tests_by_task(
+            self.task_id,
+            status=status,
+            execution=self.execution if execution is None else execution,
+        )
+
+    def get_execution_tasks(
+        self, filter_fn: Optional[Callable[["Task"], bool]] = None
+    ) -> Optional[List["Task"]]:
+        """
+        Get a list of execution tasks associated with this task.
+
+        If this is a display task, return the tasks execution tasks associated with it. 
+        If this is not a display task, returns None.
+
+        :param filter_fn: Function to filter returned results.
+        :return: List of execution tasks.
+        """
+        if self.display_only:
+            execution_tasks = [
+                self._api.task_by_id(task_id, fetch_all_executions=True)
+                for task_id in self.execution_tasks
+            ]
+
+            execution_tasks = [
+                task.get_execution_or_self(self.execution) for task in execution_tasks
+            ]
+
+            if filter_fn:
+                return [task for task in execution_tasks if filter_fn(task)]
+            return execution_tasks
+
+        return None
 
     def __repr__(self) -> str:
         """
